# Managing Users
### On this page
  * [Authentication and Authorization](https://help.sap.com/docs/leanix/ea/managing-users#authentication-and-authorization)
  * [Managing Users Without SSO](https://help.sap.com/docs/leanix/ea/managing-users#managing-users-without-sso)
  * [Inviting Users](https://help.sap.com/docs/leanix/ea/managing-users#inviting-users)
  * [Managing Roles](https://help.sap.com/docs/leanix/ea/managing-users#managing-roles)
  * [Deactivating Users](https://help.sap.com/docs/leanix/ea/managing-users#deactivating-users)
  * [Managing Users with SSO](https://help.sap.com/docs/leanix/ea/managing-users#managing-users-with-sso)
  * [Inviting Users](https://help.sap.com/docs/leanix/ea/managing-users#inviting-users-1)
  * [Managing Roles](https://help.sap.com/docs/leanix/ea/managing-users#managing-roles-1)
  * [Deactivating Users](https://help.sap.com/docs/leanix/ea/managing-users#deactivating-users-1)


Learn how to manage user access and roles with and without single sign-on (SSO).
As you begin your journey with SAP LeanIX, managing user access and roles directly within the application is a straightforward way to get started. Later, you can set up SSO for a more efficient and streamlined user management experience. You can view workspace users in the Users section of the administration area. For more information, see [Users Overview](https://help.sap.com/docs/leanix/ea/users-overview?locale=en-US&state=PRODUCTION&version=CLOUD "View workspace users and manage their access permissions and roles.").
